@@ -25,8 +25,9 @@
 
 #include <kbookmarkmanager.h>
 #include <kiconloader.h>
-#include <kdirlister.h>
 #include <klocalizedstring.h>
+#include <KConfig>
+#include <KConfigGroup>
 #include <solid/block.h>
 #include <solid/opticaldisc.h>
 #include <solid/opticaldrive.h>
@@ -35,25 +36,25 @@
 #include <solid/storagedrive.h>
 #include <solid/portablemediaplayer.h>
 
+static bool isTrash(const KBookmark &bk) {
+    return bk.url().toString() == QLatin1String("trash:/");
+}
+
 KFilePlacesItem::KFilePlacesItem(KBookmarkManager *manager,
                                  const QString &address,
                                  const QString &udi)
-    : m_manager(manager), m_lister(0), m_folderIsEmpty(true), m_isCdrom(false),
+    : m_manager(manager), m_folderIsEmpty(true), m_isCdrom(false),
       m_isAccessible(false), m_device(udi)
 {
     setBookmark(m_manager->findByAddress(address));
 
-    if (udi.isEmpty() && m_bookmark.metaDataItem("ID").isEmpty()) {
-        m_bookmark.setMetaDataItem("ID", generateNewId());
+    if (udi.isEmpty() && m_bookmark.metaDataItem(QStringLiteral("ID")).isEmpty()) {
+        m_bookmark.setMetaDataItem(QStringLiteral("ID"), generateNewId());
     } else if (udi.isEmpty()) {
-        if (hasFullIcon(m_bookmark)) {
-            // TODO if this is only for the trash, it would be much faster to just read trashrc
-            m_lister = new KDirLister(this);
-            m_lister->setAutoErrorHandlingEnabled(false, 0); // don't bother the user if trash:/ doesn't exist
-            m_lister->setDelayedMimeTypes(true); // we don't need the mimetypes, so don't penalize other KDirLister users
-            connect(m_lister, SIGNAL(completed()),
-                    this, SLOT(onListerCompleted()));
-            m_lister->openUrl(m_bookmark.url());
+        if (isTrash(m_bookmark)) {
+            KConfig cfg(QStringLiteral("trashrc"), KConfig::SimpleConfig);
+            const KConfigGroup group = cfg.group("Status");
+            m_folderIsEmpty = group.readEntry("Empty", true);
         }
     } else if (!udi.isEmpty() && m_device.isValid()) {
         m_access = m_device.as<Solid::StorageAccess>();
@@ -77,15 +78,15 @@ KFilePlacesItem::~KFilePlacesItem()
 QString KFilePlacesItem::id() const
 {
     if (isDevice()) {
-        return bookmark().metaDataItem("UDI");
+        return bookmark().metaDataItem(QStringLiteral("UDI"));
     } else {
-        return bookmark().metaDataItem("ID");
+        return bookmark().metaDataItem(QStringLiteral("ID"));
     }
 }
 
 bool KFilePlacesItem::isDevice() const
 {
-    return !bookmark().metaDataItem("UDI").isEmpty();
+    return !bookmark().metaDataItem(QStringLiteral("UDI")).isEmpty();
 }
 
 KBookmark KFilePlacesItem::bookmark() const
@@ -97,7 +98,7 @@ void KFilePlacesItem::setBookmark(const KBookmark &bookmark)
 {
     m_bookmark = bookmark;
 
-    if (bookmark.metaDataItem("isSystemItem") == "true") {
+    if (bookmark.metaDataItem(QStringLiteral("isSystemItem")) == QLatin1String("true")) {
         // This context must stay as it is - the translated system bookmark names
         // are created with 'KFile System Bookmarks' as their context, so this
         // ensures the right string is picked from the catalog.
@@ -107,22 +108,41 @@ void KFilePlacesItem::setBookmark(const KBookmark &bookmark)
     } else {
         m_text = bookmark.text();
     }
+
+    const GroupType type = groupType();
+    switch (type) {
+    case PlacesType:
+        m_groupName = i18nc("@item", "Places");
+        break;
+    case RecentlySavedType:
+        m_groupName = i18nc("@item", "Recently Saved");
+        break;
+    case SearchForType:
+        m_groupName = i18nc("@item", "Search For");
+        break;
+    case DevicesType:
+        m_groupName = i18nc("@item", "Devices");
+        break;
+    default:
+        Q_UNREACHABLE();
+        break;
+    }
 }
 
 Solid::Device KFilePlacesItem::device() const
 {
     if (m_device.udi().isEmpty()) {
-        m_device = Solid::Device(bookmark().metaDataItem("UDI"));
+        m_device = Solid::Device(bookmark().metaDataItem(QStringLiteral("UDI")));
         if (m_device.isValid()) {
             m_access = m_device.as<Solid::StorageAccess>();
             m_volume = m_device.as<Solid::StorageVolume>();
             m_disc = m_device.as<Solid::OpticalDisc>();
             m_mtp = m_device.as<Solid::PortableMediaPlayer>();
         } else {
-            m_access = 0;
-            m_volume = 0;
-            m_disc = 0;
-            m_mtp = 0;
+            m_access = nullptr;
+            m_volume = nullptr;
+            m_disc = nullptr;
+            m_mtp = nullptr;
         }
     }
     return m_device;
@@ -130,15 +150,38 @@ Solid::Device KFilePlacesItem::device() const
 
 QVariant KFilePlacesItem::data(int role) const
 {
-    QVariant returnData;
-
-    if (role != KFilePlacesModel::HiddenRole && role != Qt::BackgroundRole && isDevice()) {
-        returnData = deviceData(role);
+    if (role == KFilePlacesModel::GroupRole) {
+        return QVariant(m_groupName);
+    } else if (role != KFilePlacesModel::HiddenRole &&
+                role != Qt::BackgroundRole && isDevice()) {
+        return deviceData(role);
     } else {
-        returnData = bookmarkData(role);
+        return bookmarkData(role);
+    }
+}
+
+KFilePlacesItem::GroupType KFilePlacesItem::groupType() const
+{
+    if (!isDevice()) {
+        const QString protocol = bookmark().url().scheme();
+        if (protocol == QLatin1String("timeline")) {
+            return RecentlySavedType;
+        }
+
+        if (protocol.contains(QLatin1String("search"))) {
+            return SearchForType;
+        }
+
+        if (protocol == QLatin1String("bluetooth") ||
+            protocol == QLatin1String("obexftp") ||
+            protocol == QLatin1String("kdeconnect")) {
+            return DevicesType;
+        }
+
+        return PlacesType;
     }
 
-    return returnData;
+    return DevicesType;
 }
 
 QVariant KFilePlacesItem::bookmarkData(int role) const
@@ -155,17 +198,17 @@ QVariant KFilePlacesItem::bookmarkData(int role) const
     case Qt::DecorationRole:
         return QIcon::fromTheme(iconNameForBookmark(b));
     case Qt::BackgroundRole:
-        if (b.metaDataItem("IsHidden") == "true") {
+        if (b.metaDataItem(QStringLiteral("IsHidden")) == QLatin1String("true")) {
             return QColor(Qt::lightGray);
         } else {
             return QVariant();
         }
     case KFilePlacesModel::UrlRole:
-        return QUrl(b.url());
+        return b.url();
     case KFilePlacesModel::SetupNeededRole:
         return false;
     case KFilePlacesModel::HiddenRole:
-        return b.metaDataItem("IsHidden") == "true";
+        return b.metaDataItem(QStringLiteral("IsHidden")) == QLatin1String("true");
     default:
         return QVariant();
     }
@@ -189,14 +232,14 @@ QVariant KFilePlacesItem::deviceData(int role) const
                 Solid::Block *block = d.as<Solid::Block>();
                 if (block) {
                     QString device = block->device();
-                    return QUrl(QString("audiocd:/?device=%1").arg(device));
+                    return QUrl(QStringLiteral("audiocd:/?device=%1").arg(device));
                 }
                 // We failed to get the block device. Assume audiocd:/ can
                 // figure it out, but cannot handle multiple disc drives.
                 // See https://bugs.kde.org/show_bug.cgi?id=314544#c40
-                return QUrl(QString("audiocd:/"));
+                return QUrl(QStringLiteral("audiocd:/"));
             } else if (m_mtp) {
-                return QUrl(QString("mtp:udi=%1").arg(d.udi()));
+                return QUrl(QStringLiteral("mtp:udi=%1").arg(d.udi()));
             } else {
                 return QVariant();
             }
@@ -208,13 +251,13 @@ QVariant KFilePlacesItem::deviceData(int role) const
             }
 
         case KFilePlacesModel::FixedDeviceRole: {
-            Solid::StorageDrive *drive = 0;
+            Solid::StorageDrive *drive = nullptr;
             Solid::Device parentDevice = m_device;
             while (parentDevice.isValid() && !drive) {
                 drive = parentDevice.as<Solid::StorageDrive>();
                 parentDevice = parentDevice.parent();
             }
-            if (drive != 0) {
+            if (drive != nullptr) {
                 return !drive->isHotpluggable() && !drive->isRemovable();
             }
             return true;
@@ -246,11 +289,11 @@ KBookmark KFilePlacesItem::createBookmark(KBookmarkManager *manager,
         if (empty_icon.endsWith(QLatin1String("-full"))) {
             empty_icon.chop(5);
         } else if (empty_icon.isEmpty()) {
-            empty_icon = "user-trash";
+            empty_icon = QStringLiteral("user-trash");
         }
     }
     KBookmark bookmark = root.addBookmark(label, url, empty_icon);
-    bookmark.setMetaDataItem("ID", generateNewId());
+    bookmark.setMetaDataItem(QStringLiteral("ID"), generateNewId());
 
     if (after) {
         root.moveBookmark(bookmark, after->bookmark());
@@ -270,7 +313,7 @@ KBookmark KFilePlacesItem::createSystemBookmark(KBookmarkManager *manager,
 
     KBookmark bookmark = createBookmark(manager, untranslatedLabel, url, iconName);
     if (!bookmark.isNull()) {
-        bookmark.setMetaDataItem("isSystemItem", "true");
+        bookmark.setMetaDataItem(QStringLiteral("isSystemItem"), QStringLiteral("true"));
     }
     return bookmark;
 }
@@ -283,8 +326,8 @@ KBookmark KFilePlacesItem::createDeviceBookmark(KBookmarkManager *manager,
         return KBookmark();
     }
     KBookmark bookmark = root.createNewSeparator();
-    bookmark.setMetaDataItem("UDI", udi);
-    bookmark.setMetaDataItem("isSystemItem", "true");
+    bookmark.setMetaDataItem(QStringLiteral("UDI"), udi);
+    bookmark.setMetaDataItem(QStringLiteral("isSystemItem"), QStringLiteral("true"));
     return bookmark;
 }
 
@@ -294,7 +337,7 @@ QString KFilePlacesItem::generateNewId()
 
 //    return QString::number(count++);
 
-    return QString::number(QDateTime::currentDateTime().toTime_t())
+    return QString::number(QDateTime::currentDateTimeUtc().toTime_t())
            + '/' + QString::number(count++);
 
 //    return QString::number(QDateTime::currentDateTime().toTime_t())
@@ -310,24 +353,13 @@ void KFilePlacesItem::onAccessibilityChanged(bool isAccessible)
     emit itemChanged(id());
 }
 
-bool KFilePlacesItem::hasFullIcon(const KBookmark &bookmark) const
-{
-    return bookmark.url().toString() == QLatin1String("trash:/");
-}
-
 QString KFilePlacesItem::iconNameForBookmark(const KBookmark &bookmark) const
 {
-    if (!m_folderIsEmpty && hasFullIcon(bookmark)) {
+    if (!m_folderIsEmpty && isTrash(bookmark)) {
         return bookmark.icon() + "-full";
     } else {
         return bookmark.icon();
     }
 }
 
-void KFilePlacesItem::onListerCompleted()
-{
-    m_folderIsEmpty = m_lister->items().isEmpty();
-    emit itemChanged(id());
-}
-
 #include "moc_kfileplacesitem_p.cpp"
